style property
Custom styling for the TeXView container.
This allows you to control properties like margins, padding, and background color.
Implementation
final TeXViewStyle? style;
Custom styling for the TeXView container.
This allows you to control properties like margins, padding, and background color.
final TeXViewStyle? style;